@@ -3,7 +3,6 @@ from enum import Enum, auto
 import logging
 import requests
 from pkg_resources import parse_version
-from pprint import pprint
 
 logger = logging.getLogger(__name__)
 
@@ -23,14 +22,12 @@ def check_outdated(version: str, package: str = 'dummy_autoupdate') -> CheckVers
 
     try:
         response = requests.get(url).text
-        # logger.debug(f'result: {response}')
     except requests.ConnectionError:
         logger.info(f'No internet.')
         return CheckVersionMessage.no_internet
 
     try:
         current_version = parse_version(version)
-        pprint(json.loads(response))
         latest_version = json.loads(response)['info']['version']
         latest_version = parse_version(latest_version)
 
