@@ -18,16 +18,16 @@ class MainWindow(QWidget):
     def __init__(self, version: str):
         super().__init__()
         self.status = CheckVersionMessage.not_checked
+        self.current_version = version
 
-        self.wait_window = WaitWindow()
+        self.wait_window = WaitWindow(f'You use the version {version}.')
         self.debug_window = QTextEditLogger()
+
         self.wait_window.sigUpdateClicked.connect(self._update_version)
         self.wait_window.sigRestartClicked.connect(self.restart)
+        self.wait_window.sigCheckClicked.connect(self.check_version)
+
         self.q_thread_pool = QThreadPool()
-        self.worker = Worker(check_outdated, version)
-        self.worker.signals.result.connect(self.wait_window.get_result)
-        self.worker.signals.result.connect(self._set_status)
-        self.q_thread_pool.start(self.worker)
 
     @pyqtSlot(object, name='setStatus')
     def _set_status(self, res: CheckVersionMessage):
@@ -35,7 +35,7 @@ class MainWindow(QWidget):
 
     @pyqtSlot(name='updateVersion')
     def _update_version(self):
-
+        self.wait_window.on_update()
         try:
             version = self.status.version
         except AttributeError:
@@ -45,6 +45,15 @@ class MainWindow(QWidget):
         self.worker.signals.result.connect(self._on_updated)
         self.q_thread_pool.start(self.worker)
 
+    @pyqtSlot(name='checkVerison')
+    def check_version(self):
+        self.wait_window.on_checking()
+
+        self.worker = Worker(check_outdated, self.current_version)
+        self.worker.signals.result.connect(self.wait_window.get_result)
+        self.worker.signals.result.connect(self._set_status)
+        self.q_thread_pool.start(self.worker)
+
     @pyqtSlot(object, name='onUpdatedFinished')
     def _on_updated(self, updated: bool):
         if updated:
